@@ -3,9 +3,9 @@
  *
  *	Created by:	John T. Kohl
  *
- *	$Source: /afs/dev.mit.edu/source/repository/athena/lib/zephyr/server/bdump.c,v $
- *	$Id: bdump.c 2623 2010-12-19 20:03:10Z kcr@ATHENA.MIT.EDU $
- *	$Author: kcr@ATHENA.MIT.EDU $
+ *	$Source$
+ *	$Id$
+ *	$Author$
  *
  *	Copyright (c) 1987,1988,1991 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
@@ -17,7 +17,7 @@
 #include <sys/socket.h>
 
 #ifndef lint
-static const char rcsid_bdump_c[] = "$Id: bdump.c 2623 2010-12-19 20:03:10Z kcr@ATHENA.MIT.EDU $";
+static const char rcsid_bdump_c[] = "$Id$";
 #endif /* lint */
 
 #ifndef MIN
