@@ -3,8 +3,8 @@
  *
  *	Created by:	John T. Kohl
  *
- *	$Source: /afs/dev.mit.edu/source/repository/athena/lib/zephyr/server/class.c,v $
- *	$Author: kcr@ATHENA.MIT.EDU $
+ *	$Source$
+ *	$Author$
  *
  *	Copyright (c) 1987 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
@@ -17,7 +17,7 @@
 
 #if !defined (lint) && !defined (SABER)
 static const char rcsid_class_c[] =
-"$Id: class.c 2527 2009-08-09 18:42:32Z kcr@ATHENA.MIT.EDU $";
+"$Id$";
 #endif
 
 /*
