@@ -3,8 +3,8 @@
  *
  *	Created by:	John T. Kohl
  *
- *	$Source: /afs/dev.mit.edu/source/repository/athena/lib/zephyr/server/dispatch.c,v $
- *	$Author: kcr@ATHENA.MIT.EDU $
+ *	$Source$
+ *	$Author$
  *
  *	Copyright (c) 1987, 1991 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
@@ -18,7 +18,7 @@
 #ifndef lint
 #ifndef SABER
 static const char rcsid_dispatch_c[] =
-"$Id: dispatch.c 2595 2010-08-24 08:36:13Z kcr@ATHENA.MIT.EDU $";
+"$Id$";
 #endif
 #endif
 
