@@ -8,15 +8,15 @@
  *	"mit-copyright.h".
  */
 /*
- *	$Source: /afs/dev.mit.edu/source/repository/athena/lib/zephyr/server/kstuff.c,v $
- *	$Header: /afs/dev.mit.edu/source/repository/athena/lib/zephyr/server/kstuff.c,v 1.27 2004/02/29 06:34:04 zacheiss Exp $
+ *	$Source$
+ *	$Header$
  */
 
 #include "zserver.h"
 
 #ifndef lint
 #ifndef SABER
-static const char rcsid_kstuff_c[] = "$Id: kstuff.c 2630 2011-02-02 05:26:26Z kcr@ATHENA.MIT.EDU $";
+static const char rcsid_kstuff_c[] = "$Id$";
 #endif
 #endif
 
