@@ -3,8 +3,8 @@
  *
  *	Created by:	John T. Kohl
  *
- *	$Source: /afs/dev.mit.edu/source/repository/athena/lib/zephyr/server/server.c,v $
- *	$Author: kcr@ATHENA.MIT.EDU $
+ *	$Source$
+ *	$Author$
  *
  *	Copyright (c) 1987, 1991 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
@@ -17,7 +17,7 @@
 
 #ifndef lint
 #ifndef SABER
-static const char rcsid_server_c[] = "$Id: server.c 2630 2011-02-02 05:26:26Z kcr@ATHENA.MIT.EDU $";
+static const char rcsid_server_c[] = "$Id$";
 #endif
 #endif
 
@@ -457,7 +457,7 @@ server_timo(void *arg)
 	auth = 0;
 	break;
       default:
-	syslog(LOG_ERR,"Bad server state, server 0x%x\n", (int)which);
+	syslog(LOG_ERR,"Bad server state, server 0x%p\n", which);
 	abort();
     }
     /* now he's either TARDY, STARTING, or DEAD
