@@ -3,8 +3,8 @@
  *
  *	Created by:	John T. Kohl
  *
- *	$Source: /afs/dev.mit.edu/source/repository/athena/lib/zephyr/server/subscr.c,v $
- *	$Author: kcr@ATHENA.MIT.EDU $
+ *	$Source$
+ *	$Author$
  *
  *	Copyright (c) 1987,1988 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
@@ -16,7 +16,7 @@
 
 #ifndef lint
 #ifndef SABER
-static const char rcsid_subscr_c[] = "$Id: subscr.c 2572 2010-07-28 00:50:42Z kcr@ATHENA.MIT.EDU $";
+static const char rcsid_subscr_c[] = "$Id$";
 #endif
 #endif
 
